summaryrefslogtreecommitdiffstats
path: root/src/usr/htmgt/htmgt_cfgdata.H
diff options
context:
space:
mode:
authorChris Cain <cjcain@us.ibm.com>2017-12-12 12:51:10 -0600
committerWilliam G. Hoffa <wghoffa@us.ibm.com>2017-12-15 16:15:43 -0500
commit83243d5bbb3db4a79441824d5a4b4a250554f841 (patch)
treeb0dbe40f07358899e71fb98626b1138cd2711540 /src/usr/htmgt/htmgt_cfgdata.H
parent02098ca7d9c127a77b88692f1569938679e8c105 (diff)
downloadtalos-hostboot-83243d5bbb3db4a79441824d5a4b4a250554f841.tar.gz
talos-hostboot-83243d5bbb3db4a79441824d5a4b4a250554f841.zip
HTMGT: Send power supply redundancy policy to OCC
Change-Id: If439440e0a4368e51de91818f406f152f5e232b1 CQ: SW408974 Reviewed-on: http://ralgit01.raleigh.ibm.com/gerrit1/50824 Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: Martha Broyles <mbroyles@us.ibm.com> Tested-by: Jenkins OP Build CI <op-jenkins+hostboot@us.ibm.com> Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins OP HW <op-hw-jenkins+hostboot@us.ibm.com> Reviewed-by: Christopher J. Cain <cjcain@us.ibm.com> Reviewed-by: William G. Hoffa <wghoffa@us.ibm.com>
Diffstat (limited to 'src/usr/htmgt/htmgt_cfgdata.H')
-rw-r--r--src/usr/htmgt/htmgt_cfgdata.H6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/usr/htmgt/htmgt_cfgdata.H b/src/usr/htmgt/htmgt_cfgdata.H
index 84d936dfa..5349ea600 100644
--- a/src/usr/htmgt/htmgt_cfgdata.H
+++ b/src/usr/htmgt/htmgt_cfgdata.H
@@ -66,6 +66,7 @@ namespace HTMGT
//KVM or OPAL mode + single node
OCC_CFGDATA_OPENPOWER_OPALVM = 0x81,
//PowerVM mode + single node
+ OCC_CFGDATA_NON_REDUNDANT_PS = 0x02,
OCC_CFGDATA_OPENPOWER_POWERVM = 0x01,
//Mask, report throttling only when max frequency lowered below nominal
@@ -193,10 +194,11 @@ namespace HTMGT
* Value is read from the MRW based on the Current Power Supply
* Redundancy Policy sensor in the BMC
*
* @param[in] i_sys - pointer to system target
* @returns maximum power cap in watts
*/
- uint16_t getMaxPowerCap(TARGETING::Target * i_sys);
+ uint16_t getMaxPowerCap(TARGETING::Target *i_sys, bool & o_is_redundant);
/**
OpenPOWER on IntegriCloud
@@ -193,10 +194,11 @@ namespace HTMGT
* Redundancy Policy sensor in the BMC
*
- * @param[in] i_sys - pointer to system target
+ * @param[in] i_sys - pointer to system target
+ * @param[out] o_is_redundant - true if power supplies should be redundant
* @returns maximum power cap in watts
*/